@@ -1,11 +1,14 @@
 from django.urls import path
 
-from .views import BOOK, QUOTE, SampleBookDetail, homepage_view
+from bookmarks.utils import Pathmaker
+
+from .models import SampleBook, SampleQuote
+from .views import SampleBookDetail, homepage_view
 
 app_name = "examples"
 urlpatterns = (
-    BOOK.make_patterns()
-    + QUOTE.make_patterns()
+    Pathmaker(SampleBook).make_patterns()
+    + Pathmaker(SampleQuote).make_patterns()
     + [
         path(
             "book/detail/<int:pk>",
